# Observations

Observations provide a high-level interface to retrieve observation data that is being created during execution.

{% machinable.Observations %}

{% machinable.observations.collections.Collection %}

{% machinable.observations.views.observation.Observation %}

{% machinable.observations.observations.ObservationsQueryBuilder %}

{% machinable.observations.views.records.Records::{'include': ['refresh', 'info', 'query', 'find_all', 'find', 'find_many', 'as_dataframe']} %}

{% machinable.observations.views.records.RecordsQueryBuilder %}

{% machinable.observations.views.task.Task %}


